@@ -1,6 +1,6 @@
 fn main() {
     let number = "T-H-R-E-E"; // Don't change this line
-    println!("Spell a number: {}", number);
+    println!("Spell a number: {number}");
 
     // TODO: Fix the compiler error by changing the line below without renaming the variable.
     number = 3;
