@@ -4,9 +4,11 @@
 #[rustfmt::skip]
 #[allow(unused_variables, unused_assignments)]
 fn main() {
-    let my_option: Option<()> = None;
+    let my_option: Option<&str> = None;
+    // Assume that you don't know the value of `my_option`.
+    // In the case of `Some`, we want to print its value.
     if my_option.is_none() {
-        println!("{:?}", my_option.unwrap());
+        println!("{}", my_option.unwrap());
     }
 
     let my_arr = &[
