@@ -9,8 +9,8 @@ cargo upgrades
 # Similar to CI
 cargo clippy -- --deny warnings
 cargo fmt --all --check
-cargo test --workspace --all-targets
-cargo run -- dev check --require-solutions
+cargo test --workspace
+cargo dev check --require-solutions
 
 # MSRV
-cargo +1.80 run -- dev check --require-solutions
+cargo +1.88 dev check --require-solutions
