@@ -10,7 +10,7 @@ fn main() {
     // Solution 1: Matching over the `Option` (not `&Option`) but without moving
     // out of the `Some` variant.
     match optional_point {
-        Some(ref p) => println!("Co-ordinates are {},{}", p.x, p.y),
+        Some(ref p) => println!("Coordinates are {},{}", p.x, p.y),
         //   ^^^ added
         _ => panic!("No match!"),
     }
@@ -18,7 +18,8 @@ fn main() {
     // Solution 2: Matching over a reference (`&Option`) by added `&` before
     // `optional_point`.
     match &optional_point {
-        Some(p) => println!("Co-ordinates are {},{}", p.x, p.y),
+        //^ added
+        Some(p) => println!("Coordinates are {},{}", p.x, p.y),
         _ => panic!("No match!"),
     }
 
