@@ -5,11 +5,7 @@
 
 fn longest<'a>(x: &'a str, y: &'a str) -> &'a str {
     //    ^^^^     ^^          ^^          ^^
-    if x.len() > y.len() {
-        x
-    } else {
-        y
-    }
+    if x.len() > y.len() { x } else { y }
 }
 
 fn main() {
