@@ -1,4 +1,4 @@
-use anyhow::{bail, Context, Result};
+use anyhow::{Context, Result, bail};
 use clap::Subcommand;
 use std::path::PathBuf;
 
@@ -8,7 +8,7 @@ mod update;
 
 #[derive(Subcommand)]
 pub enum DevCommands {
-    /// Create a new project for third-party Rustlings exercises
+    /// Create a new project for community exercises
     New {
         /// The path to create the project in
         path: PathBuf,
